summaryrefslogtreecommitdiffstats
path: root/korundum/rubylib/examples/RubberDoc.rb
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-26 13:17:00 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-26 13:17:00 -0600
commit2d84c9d3ad0aaea0620658024537d54e6a7939f4 (patch)
tree35675532f42e78dbfcd56c6b344e1f0e79013a2e /korundum/rubylib/examples/RubberDoc.rb
parent980972d200e109a643e5a10037d7f9fcf02382ed (diff)
downloadtdebindings-2d84c9d3ad0aaea0620658024537d54e6a7939f4.tar.gz
tdebindings-2d84c9d3ad0aaea0620658024537d54e6a7939f4.zip
Rename a number of libraries and executables to avoid conflicts with KDE4
Diffstat (limited to 'korundum/rubylib/examples/RubberDoc.rb')
-rwxr-xr-xkorundum/rubylib/examples/RubberDoc.rb26
1 files changed, 13 insertions, 13 deletions
diff --git a/korundum/rubylib/examples/RubberDoc.rb b/korundum/rubylib/examples/RubberDoc.rb
index 1b196999..a5cc35cb 100755
--- a/korundum/rubylib/examples/RubberDoc.rb
+++ b/korundum/rubylib/examples/RubberDoc.rb
@@ -183,7 +183,7 @@ module MyGui
TQt::Object.connect @listbox, SIGNAL("clicked(TQListBoxItem*)"),
self, SLOT("clicked_result(TQListBoxItem*)")
TQt::Object.connect @viewed, SIGNAL("completed()"),
- self, SLOT("khtml_part_init_complete()")
+ self, SLOT("tdehtml_part_init_complete()")
TQt::Object::connect @viewed, SIGNAL("setWindowCaption(const TQString&)"),
@viewed.widget.topLevelWidget,
@@ -501,7 +501,7 @@ module HTMLIndexer
end
# TODO - this sucks, use khtml to get the values
module IDS
A = 1
META = 62
@@ -865,7 +865,7 @@ end
class RubberDoc < TQt::VBox
- slots "khtml_part_init_complete()",
+ slots "tdehtml_part_init_complete()",
"go_back()", "go_forward()", "go_home()", "goto_url()",
"goto_search()", "clicked_result(TQListBoxItem*)",
"search(const TQString&)", "update_highlight()",
@@ -926,20 +926,20 @@ class RubberDoc < TQt::VBox
def blah_blah
save_indexes
init_blah
- khtml_part_init_complete
+ tdehtml_part_init_complete
end
def quit
@main.close
end
- def khtml_part_init_complete
+ def tdehtml_part_init_complete
TQt::Object.disconnect @viewed, SIGNAL("completed()"),
- self, SLOT("khtml_part_init_complete()") if @init_connected
+ self, SLOT("tdehtml_part_init_complete()") if @init_connected
@pref = File.dirname first_url.url.gsub("file:","")
- init_khtml_part_settings @viewed if @init_connected
+ init_tdehtml_part_settings @viewed if @init_connected
index_documents
# maybe make a better choice as to the start page???
@@ -959,11 +959,11 @@ class RubberDoc < TQt::VBox
save_indexes
end
- def init_khtml_part_settings khtmlpart
- khtmlpart.setJScriptEnabled true
- khtmlpart.setJavaEnabled false
- khtmlpart.setPluginsEnabled false
- khtmlpart.setAutoloadImages false
+ def init_tdehtml_part_settings tdehtmlpart
+ tdehtmlpart.setJScriptEnabled true
+ tdehtmlpart.setJavaEnabled false
+ tdehtmlpart.setPluginsEnabled false
+ tdehtmlpart.setAutoloadImages false
end
def load_page
@@ -1248,7 +1248,7 @@ can't get tabwidget working. umm... wonder what i'm messing up... (RECHECK)
# possible BUG DOM::Text.new(node).data.string # strange that this one doesn't work... (RECHECK)
-wierd khtml bug
+wierd tdehtml bug
@rightpane.setResizeMode @viewed, TQt::Splitter::KeepSize
in order to use KURL's as constants one must place this TDEApplication init
@@ -501,7 +501,7 @@ module HTMLIndexer
end
-# TODO - this sucks, use khtml to get the values
+# TODO - this sucks, use tdehtml to get the values
module IDS
A = 1